#
# spec file for package plymouth
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# plymouth's X11 renderer adds many GTK3 packages to the build cycle,
# it is not used in the production environment.
%bcond_with x11_renderer

%global soversion 5

Name:           plymouth
Version:        22.02.122+94.4bd41a3
Release:        10.1
Summary:        Graphical Boot Animation and Logger
License:        GPL-2.0-or-later
Group:          System/Base
URL:            https://www.freedesktop.org/wiki/Software/Plymouth
Source0:        %{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE plymouth-dracut-path.patch tittiatcoke@gmail.com -- Prefix is /usr/sbin and /usr/bin
Patch0:         plymouth-dracut-path.patch
# PATCH-FIX-OPENSUSE plymouth-some-greenish-openSUSE-colors.patch bnc#886148 fcrozat@suse.com -- To use suse colors in tribar.
Patch1:         plymouth-some-greenish-openSUSE-colors.patch
# PATCH-FIX-UPSTREAM plymouth-manpages.patch bnc#871419 idoenmez@suse.de -- Fix man page installation
Patch2:         plymouth-manpages.patch
# PATCH-FIX-OPENSUSE plymouth-disable-fedora-logo.patch qzhao@suse.com -- Disable the fedora logo reference which is not in openSUSE.
Patch3:         plymouth-disable-fedora-logo.patch
# PATCH-FIX-OPENSUSE plymouth-only_use_fb_for_cirrus_bochs.patch bnc#888590 boo#1172028 bsc#1181913 fvogt@suse.com -- Force fb for cirrus and bochs, force drm otherwise. replace removal of framebuffer driver and plymouth-ignore-cirrusdrm.patch with single patch.
Patch4:         plymouth-only_use_fb_for_cirrus_bochs.patch
# PATCH-FIX-OPENSUSE plymouth-keep-KillMode-none.patch bsc#1177082 bsc#1184087 boo#1182145 qzhao@suse.com -- Keep the plymouth-start.service KillMode=none.
Patch5:         plymouth-keep-KillMode-none.patch
# PATCH-FIX-OPENSUSE plymouth-install-label-library-and-font-file-to-initrd.patch boo#1183425 boo#1184309 qzhao@suse.com -- Pack label plugin and font into initram to ensure notice info could successfully show when partition encrypted.
Patch6:         plymouth-install-label-library-and-font-file-to-initrd.patch
# PATCH-FIX-OPENSUSE plymouth-quiet-dracut-build-info.patch bsc#1189613 qzhao@suse.com -- Hide unuseful output when re-generate initrd.
Patch7:         plymouth-quiet-dracut-build-info.patch
# PATCH-FIX-OPENSUSE plymouth-watermark-config.patch bsc#1189613 qzhao@suse.com -- Add two-step water mark config support.
Patch8:         plymouth-watermark-config.patch
# PATCH-FIX-OPENSUSE plymouth-log-on-default.patch bsc#1193736 qzhao@suse.com -- Enable plymouth log by default, help to resolve random appear problems.
Patch9:         plymouth-log-on-default.patch
# PATCH-FIX-OPENSUSE plymouth-screen-twice-scale-on-160DPI-higher.patch boo#1183425 boo#1184309 qzhao@suse.com -- When DPI > 160, screen will scale output twice.
Patch10:        plymouth-screen-twice-scale-on-160DPI-higher.patch
# PATCH-FIX-OPENSUSE plymouth-crash-avoid-on-keyboard-remove-input-handler.patch bsc#1193736 qzhao@suse.com -- Confirm keyboard handler list not NULL before release memory to avoid crash.
Patch11:        plymouth-crash-avoid-on-keyboard-remove-input-handler.patch
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
%if 0%{suse_version} >= 1550
# regenerate_initrd_post moved to rpm-config-SUSE:initrd.macros
BuildRequires:  rpm-config-SUSE >= 0.g11
%else
BuildRequires:  suse-module-tools
%endif
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xz
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libsystemd) >= 186
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pango) >= 1.21.0
# needed for systemd-tty-ask-password-agent
BuildRequires:  pkgconfig(systemd) >= 186
%if %{with x11_renderer}
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14.0
%endif
Recommends:     %{name}-lang
Requires:       %{name}-branding
Requires:       systemd >= 186
Requires(post): coreutils
Requires(post): plymouth-scripts = %{version}
Requires(postun):coreutils
Suggests:       plymouth-plugin-label
Provides:       bootsplash = 3.5
Obsoletes:      bootsplash < 3.5
Provides:       systemd-plymouth = 44-10.2
Obsoletes:      systemd-plymouth <= 44-10.1

%description
Plymouth provides an attractive graphical boot animation in
place of the text messages that normally get shown. Text
messages are instead redirected to a log file for viewing
after boot.
%lang_package

%package -n libply%{soversion}
Summary:        Plymouth core library
Group:          System/Libraries

%description -n libply%{soversion}
This package contains the libply library used by Plymouth.

%package -n libply-boot-client%{soversion}
Summary:        Plymouth core library
Group:          System/Libraries

%description -n libply-boot-client%{soversion}
This package contains the libply-boot-client library used by Plymouth.

%package -n libply-splash-core%{soversion}
Summary:        Plymouth core library
Group:          System/Libraries

%description -n libply-splash-core%{soversion}
This package contains the libply-splash-core library
used by graphical Plymouth splashes.

%package -n libply-splash-graphics%{soversion}
Summary:        Plymouth graphics libraries
Group:          System/Libraries
BuildRequires:  libpng-devel

%description -n libply-splash-graphics%{soversion}
This package contains the libply-splash-graphics library
used by graphical Plymouth splashes.

%package branding-upstream
Summary:        Default configuration file and branding from the Plymouth upstream
Group:          System/Base
Provides:       %{name}-branding = %{version}
Conflicts:      %{name}-branding
BuildArch:      noarch

%description branding-upstream
This package contains the /usr/share/plymouthd.defaults which contains the basic
settings and branding from the upstream.

%package devel
Summary:        Libraries and headers for writing Plymouth splash plugins
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
%if %{with x11_renderer}
Requires:       %{name}-x11-renderer = %{version}
%endif
Requires:       libply%{soversion} = %{version}
Requires:       libply-boot-client%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}
Requires:       pkgconfig

%description devel
This package contains the libply and libplybootsplash libraries
and headers needed to develop 3rd party splash plugins for Plymouth.

%package dracut
Summary:        Plymouth related utilities for dracut
Group:          System/Base
Requires:       %{name} = %{version}
Supplements:    (plymouth and dracut)
BuildArch:      noarch

%description dracut
This package contains utilities that integrate dracut with Plymouth

%package x11-renderer
Summary:        Plymouth X11 renderer
Group:          System/Base
Requires:       %{name} = %{version}

%description x11-renderer
This package provides the X11 renderer which allows to test plymouth
behavior on environments with a valid DISPLAY.

%package scripts
Summary:        Plymouth related scripts
Group:          System/Base
Requires:       awk
Requires:       dracut
Requires:       grep
Requires:       sed
Requires(pre):  %{name} = %{version}
BuildArch:      noarch

%description scripts
This package contains scripts that help integrate Plymouth with
the system.

%package plugin-label
Summary:        Plymouth label plugin
Group:          System/Base
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-label
This package contains the label control plugin for
Plymouth. It provides the ability to render text on
graphical boot splashes using pango and cairo.

%package plugin-label-ft
Summary:        Plymouth FreeType label plugin
Group:          System/Base
Requires:       fontconfig
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-label-ft
This package contains the label control plugin for
Plymouth. It provides the ability to render text on
graphical boot splashes using FreeType

%package plugin-fade-throbber
Summary:        Plymouth "Fade-Throbber" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-fade-throbber
This package contains the "Fade-In" boot splash plugin for
Plymouth. It features a centered image that fades in and out
while other images pulsate around during system boot up.

%package plugin-space-flares
Summary:        Plymouth "space-flares" plugin
Group:          System/Base
Requires:       %{name}-plugin-label = %{version}
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-space-flares
This package contains the "space-flares" boot splash plugin for
Plymouth. It features a corner image with animated flares.

%package plugin-two-step
Summary:        Plymouth "two-step" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}
Requires:       plymouth-plugin-label = %{version}

%description plugin-two-step
This package contains the "two-step" boot splash plugin for
Plymouth. It features a two phased boot process that starts with
a progressing animation synced to boot time and finishes with a
short, fast one-shot animation.

%package plugin-script
Summary:        Plymouth "script" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-script
This package contains the "script" boot splash plugin for
Plymouth. It features an extensible, scriptable boot splash
language that simplifies the process of designing custom
boot splash themes.

%package plugin-tribar
Summary:        Plymouth "script" plugin
Group:          System/Base
Requires:       libply%{soversion} = %{version}
Requires:       libply-splash-core%{soversion} = %{version}
Requires:       libply-splash-graphics%{soversion} = %{version}

%description plugin-tribar
This package contains the "tribar" boot splash plugin for
Plymouth. It features an extensible, scriptable boot splash
language that simplifies the process of designing custom
boot splash themes.

%package theme-fade-in
Summary:        Plymouth "Fade-In" theme
Group:          System/Base
Requires:       %{name}-plugin-fade-throbber = %{version}
Requires:       plymouth-plugin-label = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-fade-in
This package contains the "Fade-In" boot splash theme for
Plymouth. It features a centered logo that fades in and out
while stars twinkle around the logo during system boot up.

%package theme-spinfinity
Summary:        Plymouth "Spinfinity" theme
Group:          System/Base
Requires(post): %{name}-scripts
Requires(pre):  %{name}
BuildArch:      noarch

%description theme-spinfinity
This package contains the "Spinfinity" boot splash theme for
Plymouth. It features a centered logo and animated spinner that
spins in the shape of an infinity sign.

%package theme-spinner
Summary:        Plymouth "Spinner" theme
Group:          System/Base
Requires:       %{name}-plugin-two-step = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-spinner
This package contains the "spinner" boot splash theme for
Plymouth.

%package theme-solar
Summary:        Plymouth "Solar" theme
Group:          System/Base
Requires:       %{name}-plugin-space-flares = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-solar
This package contains the "Solar" boot splash theme for
Plymouth. It features a blue flamed sun with animated solar flares.

%package theme-tribar
Summary:        Plymouth "Tribar" theme
Group:          System/Base
Requires:       %{name}-plugin-tribar = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-tribar
This package contains the "Tribar" boot splash theme for
Plymouth

%package theme-script
Summary:        Plymouth "Script" theme
Group:          System/Base
Requires:       %{name}-plugin-script = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-script
This package contains the "script" boot splash theme for
Plymouth. It is a simple example theme the uses the "script"
plugin.

%package theme-bgrt
Summary:        Plymouth "bgrt" theme
# Uses images from spinner theme
Group:          System/Base
Requires:       %{name}-plugin-two-step = %{version}
Requires:       %{name}-theme-spinner = %{version}
Requires(post): %{name}-scripts
BuildArch:      noarch

%description theme-bgrt
This package contains the "bgrt" boot splash theme for
Plymouth.

%prep
%setup -q
%autopatch -p1
autoreconf -ivf

%build
%configure \
           --enable-systemd-integration                          \
           --enable-tracing                                      \
           --disable-silent-rules                                \
           --disable-static                                      \
           --disable-upstart-monitoring                          \
           --disable-tests                                       \
%if %{without x11_renderer}
           --disable-gtk                                         \
%endif
           --with-release-file=%{_sysconfdir}/os-release         \
           --with-shutdown-tty=/dev/tty7                         \
           --with-background-start-color-stop=0x1A3D1F           \
           --with-background-end-color-stop=0x4EA65C             \
           --with-background-color=0x3391cd                      \
           --runstatedir=/run                                    \
           --without-rhgb-compat-link                            \
           --without-system-root-install

make %{?_smp_mflags}

%install
%make_install

# *.la are files generated during compilation, useless for final user.
find %{buildroot} -type f -name "*.la" -delete

# Glow isn't quite ready for primetime
rm -rf %{buildroot}%{_datadir}/plymouth/themes/glow/

# We will nolonger ship plymouthd.conf, Plymouthd will read /usr/share/plymouth/plymouthd.defaults if /etc/plymouth/plymouthd.conf doesn't exist(jsc#SLE-11637).
rm -f %{buildroot}%{_sysconfdir}/plymouth/plymouthd.conf

# Move logrotate files from user specific directory /etc/logrotate.d to vendor specific directory /usr/etc/logrotate.d.
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_distconfdir}/logrotate.d
mv %{buildroot}%{_sysconfdir}/logrotate.d/bootlog %{buildroot}%{_distconfdir}/logrotate.d/bootlog
%endif

# Split lang to seperate package.
%find_lang %{name}

%post
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}
%if 0%{?suse_version} > 1500
%service_del_postun_without_restart plymouth-halt.service plymouth-kexec.service plymouth-poweroff.service plymouth-quit-wait.service plymouth-quit.service plymouth-read-write.service plymouth-reboot.service plymouth-start.service
%else
%systemd_postun
%endif
if [ $1 -eq 0 ]; then
    rm -f %{_libdir}/plymouth/default.so
    rm -f /boot/initrd-plymouth.img
fi

%posttrans
%{?regenerate_initrd_posttrans}

%if 0%{?suse_version} > 1500
%ldconfig_scriptlets -n libply-boot-client%{soversion}
%ldconfig_scriptlets -n libply-splash-core%{soversion}
%ldconfig_scriptlets -n libply-splash-graphics%{soversion}
%ldconfig_scriptlets -n libply%{soversion}
%else
%post -n libply-boot-client%{soversion} -p /sbin/ldconfig
%postun -n libply-boot-client%{soversion} -p /sbin/ldconfig
%post -n libply-splash-core%{soversion} -p /sbin/ldconfig
%postun -n libply-splash-core%{soversion} -p /sbin/ldconfig
%post -n libply-splash-graphics%{soversion} -p /sbin/ldconfig
%postun -n libply-splash-graphics%{soversion} -p /sbin/ldconfig
%post -n libply%{soversion} -p /sbin/ldconfig
%postun -n libply%{soversion} -p /sbin/ldconfig
%endif

%post theme-spinfinity
if [ $1 -eq 1 ]; then
  set -x
  export LIB=%{_libdir}
  OTHEME="$(%{_sbindir}/plymouth-set-default-theme)"
  if [ "$OTHEME" = "text" ]; then
     if [ ! -e /.buildenv ]; then
       %{_sbindir}/plymouth-set-default-theme -R spinfinity
     else
       %{_sbindir}/plymouth-set-default-theme spinfinity
     fi
  fi
fi

%postun theme-spinfinity
if [ $1 -eq 0 ]; then
    export LIB=%{_libdir}
    if [ "$(%{_sbindir}/plymouth-set-default-theme)" = "spinfinity" ]; then
        %{_sbindir}/plymouth-set-default-theme -R --reset
    fi
fi

%post theme-fade-in
if [ $1 -eq 1 ]; then
  set -x
  export LIB=%{_libdir}
  OTHEME="$(%{_sbindir}/plymouth-set-default-theme)"
  if [ "$OTHEME" = "text" ]; then
     if [ ! -e /.buildenv ]; then
       %{_sbindir}/plymouth-set-default-theme -R fade-in
     else
       %{_sbindir}/plymouth-set-default-theme fade-in
     fi
  fi
fi

%postun theme-fade-in
if [ $1 -eq 0 ]; then
    export LIB=%{_libdir}
    if [ "$(%{_sbindir}/plymouth-set-default-theme)" = "fade-in" ]; then
        %{_sbindir}/plymouth-set-default-theme -R --reset
    fi
fi

%post theme-solar
if [ $1 -eq 1 ]; then
  set -x
  export LIB=%{_libdir}
  OTHEME="$(%{_sbindir}/plymouth-set-default-theme)"
  if [ "$OTHEME" = "text" ]; then
     if [ ! -e /.buildenv ]; then
       %{_sbindir}/plymouth-set-default-theme -R solar
     else
       %{_sbindir}/plymouth-set-default-theme solar
     fi
  fi
fi

%postun theme-solar
if [ $1 -eq 0 ]; then
    export LIB=%{_libdir}
    if [ "$(%{_sbindir}/plymouth-set-default-theme)" = "solar" ]; then
        %{_sbindir}/plymouth-set-default-theme -R --reset
    fi
fi

%files
%dir %{_sysconfdir}/plymouth
%ghost %{_sysconfdir}/plymouth/plymouthd.conf
%dir %{_datadir}/plymouth
%dir %{_datadir}/plymouth/themes
%dir %{_datadir}/plymouth/themes/details
%dir %{_datadir}/plymouth/themes/text
%dir %{_sharedstatedir}/plymouth
%dir %{_libdir}/plymouth
%dir %{_libdir}/plymouth/renderers
%if 0%{?suse_version} > 1500
%{_distconfdir}/logrotate.d/bootlog
%else
%{_sysconfdir}/logrotate.d/bootlog
%endif
%{_bindir}/plymouth
%{_sbindir}/plymouthd
%{_libdir}/plymouth/details.so
%{_libdir}/plymouth/text.so
%{_libdir}/plymouth/renderers/drm*
%{_libdir}/plymouth/renderers/frame-buffer*
%{_datadir}/plymouth/themes/details/details.plymouth
%{_datadir}/plymouth/themes/text/text.plymouth
%{_datadir}/plymouth/bizcom.png
%ghost /run/plymouth
%{_localstatedir}/spool/plymouth
%{_mandir}/man?/*
%ghost %{_localstatedir}/lib/plymouth/boot-duration
%{_unitdir}/*
%ghost %{_localstatedir}/log/boot.log
%{_libexecdir}/plymouth/plymouthd-fd-escrow
%doc AUTHORS NEWS README.md ply_header.svg
%license COPYING

%files lang -f %{name}.lang

%files branding-upstream
%{_datadir}/plymouth/plymouthd.defaults

%files dracut
%{_libexecdir}/plymouth/plymouth-populate-initrd
%{_libexecdir}/plymouth/plymouth-generate-initrd

%files devel
%{_libdir}/libply.so
%{_libdir}/libply-splash-core.so
%{_libdir}/libply-boot-client.so
%{_libdir}/libply-splash-graphics.so
%{_libdir}/pkgconfig/ply-splash-core.pc
%{_libdir}/pkgconfig/ply-splash-graphics.pc
%{_libdir}/pkgconfig/ply-boot-client.pc
%{_includedir}/plymouth-1

%files -n libply%{soversion}
%{_libdir}/libply.so*

%files -n libply-boot-client%{soversion}
%{_libdir}/libply-boot-client.so*

%files -n libply-splash-core%{soversion}
%{_libdir}/libply-splash-core.so*

%files -n libply-splash-graphics%{soversion}
%{_libdir}/libply-splash-graphics.so*

%files scripts
%dir %{_libexecdir}/plymouth
%{_libexecdir}/plymouth/plymouth-update-initrd
%{_sbindir}/plymouth-set-default-theme

%if %{with x11_renderer}
%files x11-renderer
%{_libdir}/plymouth/renderers/x11*
%endif

%files plugin-fade-throbber
%{_libdir}/plymouth/fade-throbber.so

%files plugin-label
%{_libdir}/plymouth/label-pango.so

%files plugin-label-ft
%{_libdir}/plymouth/label-freetype.so

%files plugin-script
%{_libdir}/plymouth/script.so

%files plugin-space-flares
%{_libdir}/plymouth/space-flares.so

%files plugin-tribar
%{_libdir}/plymouth/tribar.so

%files plugin-two-step
%{_libdir}/plymouth/two-step.so

%files theme-bgrt
%{_datadir}/plymouth/themes/bgrt

%files theme-fade-in
%{_datadir}/plymouth/themes/fade-in

%files theme-spinfinity
%{_datadir}/plymouth/themes/spinfinity

%files theme-script
%{_datadir}/plymouth/themes/script

%files theme-spinner
%{_datadir}/plymouth/themes/spinner

%files theme-solar
%{_datadir}/plymouth/themes/solar

%files theme-tribar
%{_datadir}/plymouth/themes/tribar

%changelog
* Mon Aug 28 2023 Cliff Zhao <qzhao@suse.com>
- Remove plymouth-runstatedir-revert.patch: Tumbleweed following
  upstream, which already support "--runstatedir", don't need this
  modification anymore(jsc#PED-5841).
* Mon Aug 28 2023 Cliff Zhao <qzhao@suse.com>
- Add plymouth-runstatedir-revert.patch: For plymouth update
  successfully build in SLE-15-SP6:GA. The current edition of
  autoconf on SLE-15-SP6:GA don't support "--runstatedir" yet, so
  reverse plymouth compile option to the old "--withruntimedir"
  (jsc#PED-5841).
* Mon May 22 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Properly list services as parameters to
  %%service_del_postun_without_restart: new versions mandate the
  parameters to further down the line eliminate errors. For the
  time being, the code does not care for the parameters.
* Tue Apr 18 2023 Cliff Zhao <qzhao@suse.com>
- Update plymouth.spec: Change bootup terminal to default to satisfy
  Nvidia proprietary driver (bsc#1208726).
* Wed Oct 26 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 22.02.122+94.4bd41a3:
  * plugins: label-freetype: Fixes calculation of line width.
  * plugins: label-freetype: Fix font alignment.
  * populate-initrd: Install label-freetype plugin into initrd if
    available.
  * plugins: Add FreeType-based label plugin.
  * ply-label: Don't crash if label plugin fails.
  * details: Don't replay boot buffer on serial consoles.
  * main: Add "reload" command.
  * ply-device-manager: Add plymouth.force-frame-buffer-on-boot
    parameter, allow to choose force framebuffer mode.
  * systemd: Add mkinitcpio support to
    plymouth-switch-root-initramfs.service.
  * Rebase plymouth-only_use_fb_for_cirrus_bochs.patch;
    for build success.
  * Rebase plymouth-watermark-config.patch;
    for build success.
  * Drop 0001-Add-label-ft-plugin.patch;
    for already merged by upstream.
  * Drop 0002-Install-label-ft-plugin-into-initrd-if-available.patch
    for already merged by upstream.
  * Drop 0003-fix_null_deref.patch
    for already merged by upstream.
  * Drop 0004-label-ft-fix-alignment.patch
    for already merged by upstream.
* Thu Oct  6 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 22.02.122+77.c09c651:
  * ply-device-manager: Move verify_drm_device() higher up in the
    file.
  * ply-device-manager: Also ignore SimpleDRM devs in coldplug
    enumeration path
  * Rebase plymouth-only_use_fb_for_cirrus_bochs.patch.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Stop providing version-release for the upstream-branding
  sub-package. It leads to publishing of every new rebuild, goes
  against the goal of reproducible builds/packages.
- Update Supplements to current standard.
* Tue Sep 13 2022 Cliff Zhao <qzhao@suse.com>
- Update plymouth-install-label-library-and-font-file-to-initrd.patch:
  avoid invalid script commands failure(bsc#1203147).
* Tue Sep 13 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 22.02.122+75.6f5dc63:
  * Fix build after README changes
* Thu Sep  8 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 22.02.122+73.9826df5:
  * Update Makefile.am
  * Add README in .md format.
* Wed Aug 31 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 22.02.122+70.614d2db:
  drm: ignore non-desktop outputs
  It doesn't make sense to display a boot screen on virtual reality
  headsets.
* Fri Aug 12 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 22.02.122+64.0b0e93c:
  plugins: splash: two-step: Secure boot check and a warning image;
  libply: ply-utils: Add ply_is_secure_boot_enabled () helper;
  * This work can be used to check the secure boot configuration and put a red
  warning image on the screen if the secure boot is disabled. Also, this
  check can be utterly disabled through the kernel parameter for testing.
  If the parameter "secure_boot.warn_if_disabled=false" appears in the
  kernel parameter, the secure boot check will be disabled.
- Rebase plymouth-watermark-config.patch;
* Thu Aug  4 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 22.02.122+60.52b0494:
  src: Run through uncrustify.
  scripts: Diff less.
  scripts: Update uncrustify config.
  src: Drop vim: lines.
  ply-utils: Drop linux/fs.h include.
  scripts: Add -B to interdiff in check-format.
- Rebase plymouth-log-on-default.patch;
- Rebase plymouth-screen-twice-scale-on-160DPI-higher.patch;
* Wed Jul 20 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 0.9.5~git20220719.9e72df3:
  Make use of standard --runstatedir flag vs custom --with-runtimedir
* Mon Jul 11 2022 Fabian Vogt <fvogt@suse.com>
- Add 0004-label-ft-fix-alignment.patch: to fix alignment with
  label-ft in some cases (boo#959986).
* Wed Jun 29 2022 Stefan Schubert <schubi@suse.com>
- Update plymouth.spec: Moved logrotate files from user specific
  directory /etc/logrotate.d to vendor specific directory
  /usr/etc/logrotate.d.
* Sun May 15 2022 Cliff Zhao <qzhao@suse.com>
- Add plymouth-crash-avoid-on-keyboard-remove-input-handler.patch:
  Confirm keyboard handler list not NULL before release memory
  to avoid crash(bsc#1193736).
* Sun May 15 2022 Hans-Peter Jansen <hpj@urpla.net>
- Update plymouth-watermark-config.patch: in order to install
  the Watermark image file to initrd
- Refresh patches to apply cleanly
* Fri May 13 2022 Cliff Zhao <qzhao@suse.com>
- Add plymouth-screen-twice-scale-on-160DPI-higher.patch:
  When screen DPI > 160, display will scale output twice
  (boo#1183425 boo#1184309).
* Mon May  9 2022 Cliff Zhao <qzhao@suse.com>
- Update plymouth.spec: change configure options --with-shutdown-tty
  from 1 to 7: Make sure shutdown display could show out
  (bsc#1141749).
* Sat Apr 30 2022 Cliff Zhao <qzhao@suse.com>
- Add plymouth-log-on-default.patch: Enable plymouth log by default,
  help to resolve random appear problems (bsc#1193736).
* Tue Apr  5 2022 Cliff Zhao <qzhao@suse.com>
- Update to version 0.9.5~git20210406.e554475:
  * client: Free command parser after event loop
  * script: Don't crash for scripts without input validation
    functions
  * script: Enforce separate lines for function parameters
  * configure: Fix help string for --with-background-end-color-stop
  * two-step: Make SHOW_ANIMATION_FRACTION configurable
  * plugin: animation should transition to the end animation
  * theme: Allow themes to configure at which percentage
  * scripts: support populating from configurable theme dir
  * main: refactor code for searching the theme path
  * main: add ThemeDir configuration option
  * Fix crash when hiding message in details splash mode
  * drm: Honour screen rotation when detecting HiDPI
  * main: add --ignore-serial-consoles option so we can ignore
    serial consoles
- Update SPEC file:
  A few minor tweaks to fix part of rpmlint error reporting.
- Drop plymouth-no-longer-modify-conf-to-drop-isopensuse-macro.patch:
  Upstream accompish this requirement in 11b0ce0: Look for config
  in runtime dir first(jsc#SLE-11637).
- Drop source boot-duration: The source is an empty file, ghost
  macro in %%files section is enough to work.
* Thu Feb 10 2022 Dirk Müller <dmueller@suse.com>
- update plymouth-install-label-library-and-font-file-to-initrd.patch:
  avoid aborting on multiple font path match, pick the first one
  (boo#1183425, boo#1195600).
* Sun Jan 30 2022 Cliff Zhao <qzhao@suse.com>
- Add plymouth-watermark-config.patch:
  Add two-step theme watermark configuration support, make the
  tumbleweed watermark could show in the boot splash (bsc#1189613).
* Sun Jan 30 2022 Cliff Zhao <qzhao@suse.com>
- Add plymouth-quiet-dracut-build-info.patch: Avoid the dracut
  building info which is useless for plymouth(bsc#1189613).
* Sun Jan 30 2022 Cliff Zhao <qzhao@suse.com>
- Add plymouth-install-label-library-and-font-file-to-initrd.patch:
  Compress label.so and current theme's font into initrd to avoid
  prompt disappear when the folder in which has been encrypt
  (boo#1183425).
* Thu Jan 13 2022 Cliff Zhao <qzhao@suse.com>
- Update SPEC file:
    Remove usermerged macro and script:
    1, currently, it blocks the building in SLE-15-SP4;
    2, plymouth already build with "without-system-root-install",
    make all binary install to /usr/bin and /usr/sbin; which
    fit for /user merge target.
    3, plymouth is not launched by user. and all system intergration
    point are called from /usr.
    4, So no change need to do, everything already works.
    Remove rm rhgb-client:
    plymouth already build with "without-rhgb-compat-link",
    rhgb doesn't generated from beginning.
    Remove "disable-libkms":
    SUSE support kms and drm very well now, plymouth works
    fine with them.
- Remove plymouth-correct-runtime-dir.patch:
    Use upstream build param "with-runtimedir=/run" to instead.
- Change plymouth-dracut build arch to noarch:
    It only contain a script.
  Change libply, libply-boot-client, libply-splash-core,
  libply-splash-graphics group from Development/Libraries/C and
  C++ to System/Libraries:
    They are plymouth and plymouthd runtime library, which install
    together with plymouth.
- Resort rpm file list.
* Tue Aug 31 2021 Cliff Zhao <qzhao@suse.com>
- Add plymouth-keep-KillMode-none.patch: Keep the plymouth-start.service
  KillMode=none. The new mothod of "mixed" KillMode could not work
  with current edition of systemd and will block system boot
  (bsc#1177082 bsc#1184087 boo#1182145).
- Update plymouth-dracut-path.patch: Make it could apply to prior
  update edition.
* Wed Aug 18 2021 pandom79@gmail.com
- Update to version 0.9.5~git20210406.e554475:
  * systemd: Add plymouth-switch-root-initramfs.service to switch back to initramfs on shutdown
  * main: Add a plymouthd-fd-escrow helper
  * main: Dump debug log to plymouth-shutdown-debug.log on shutdown/reboot
  * main: Cleanly quit on SIGTERM
  * main: Only mark plymouthd as unkillable when running from the initrd
  * ply-device-manager: Don't deactivate renderers from ply_device_manager_free ()
  * details: Clear newly added text-display before replaying log messages
  * text/tribar: Fix ply_boot_splash_hide () not clearing the terminal
  * ply-text-display: Fix bottom pixels of fbcon not getting cleared
  * ply-text-display: Only skip clearing the screen when tracing to a terminal
  * main: Redirect stdio/stderr to null when tracing to a file
  * ply-logger: Add a ply_is_tracing_to_terminal () helper
  * main: Retain splash on on_show_splash() and on_hide_splash()
  * ply-device-manager: Fix bad assertion
  * two-step: Links against libintl.so if LNS
  * The use of AM_GNU_GETTEXT_VERSION in configure.ac instructs autopoint to copy po/Makefile.in.in from the exact gettext version. It is fine if the version of gettext installed on the system has the same minor version number with the requested version, but it fails if you have a newer version of gettext because of the mismatch between autoconf macros and Makefile.in.in.
  * ply-device-manager: Speed up DRM-connector probing
  * ply-device-manager: add a verify_add_or_change() helper
  * ply-device-manager: push udev_device_get_devnode call up into on_udev_event
  * two-step: Fix unused variable compiler warning
  * scripts: Remove new-object.sh
  * two-step: Only create background_bgrt_fallback_image if use_firmware_background is set
  * two-step: Always load the BGRT fallback image
  * Fix BGRT fallback rendering
  * systemd: switch to KillMode=mixed
  * Use fallback image if BGRT is not supported
  * client: Don't wait forever for a ping reply
  * Revert "Don't wait forever for a ping reply."
  * Don't wait forever for a ping reply.
  * boot-server: Handle client disconnecting while trigger pending
  * boot-server: Ref count the connections
  * drm: Honor modes selected by the user through video= kernel cmdline argument
  * use resolution of higher res monitor for window size
  * Initialize the translations on start if they are available
  * Use the correct key name for title and subtitle
  * autogoo: use /proc/self/fd/0 instead of /dev/stdin
  * configure: bump to 0.9.6
  * Apply suggestion to .gitlab-ci.yml
  * ci: Add a `distcheck` step
  * Add CI pipeline for Plymouth
  * configure: quiet a warning
  * po: drop intltool usage
  * docs: fix man page cross-reference
  * Rename 'percent_done' to 'fraction_done'
  * main: Don't bail out of load_settings if "Theme" is missing
  * main: fix mode changing before splash is shown
  * main: switch log file when switching mode
  * two-step: Center message text within labels if labels are centered
  * drm: Do not unnecessarily get output info twice
  * ply-device-manager: Only consume one udev event at a time
  * two-step: Do not jump to end-animation on halt/reboot if it is disabled
  * Add RemainAfterExit=yes to plymouth's systemd service files
  * two-step: Add UseEndAnimation setting
  * script: add Image.Crop(x, y, width, height)
  * ply-throbber: Do not redraw when we need to stop throbbing on free
  * ply-keymap-icon: Do not draw on free
  * ply-capslock-icon: Do not draw on free
  * script: add missing unref() for system update func
  * themes: Drop UseFirmwareBackground=true from spinner/bgrt firmware-upgrade settings
  * Fix SetSystemUpdateFunction
  * event-loop: Remove ply_trace calls around the disconnect handler
  * event-loop: Fix debug-log "failed to delete fd # from epoll watch list" spam
  * terminal-session: Drop unnecessary grantpt() call.
  * build-goo: Remove vestigial remnants of old GDM integration code.
  * main: Add state variable splash_is_becoming_idle
  * configure: Update bug report URL.
  * drm: Remove reset_scan_out_buffer_if_needed() prototype declaration
  * drm: Remove unnecessary next_node helper variable
  * two-step: Remove unnecessary next_node helper variable
  * Allow running plymouth-populate-initrd in a cross-compiler environment
  * throbgress: Remove the throbgress plugin
  * drm: Remove explicit set_scan_out_buffer() from activate()
  * drm: Mark buffer as clean in ply_renderer_head_new()
  * two-step: Fix wrong horizontal position of bgrt logo on left-side-up LCD panels
  * two-step: Change keyboard-indicator positioning to fixed offset below dialog
  * themes: spinner/bgrt: Modify password dialog to match gnome 3.34 changes
  * two-step: Remove workaround for upside-down panels
  * drm: Keep hw-rotation on devices with upside down LCD panels
  * drm: Add get_primary_plane_rotation() helper function
  * systemd-ask-password-plymouth.service.in: Do not hardcode /run path to pid file
  * scripts: Add a logrotate file for /var/log/boot.log
  * drm: Install our fb after drawing to it
  * drm: Delay installing our framebuffer until the first draw
  * configure: Make runtimedir configurable
  * ply-pixel-buffer: Fix bottom edge rendering of scaled buffers
  * themes: Add images for keyboard indicator support to spinner and spinfinity
  * two-step: Add Keyboard layout indicator support
  * capslock-icon: Draw the icon on show
  * libply-splash-graphics: Add new keymap-icon control
  * scripts: Add keymap-render.py script
  * renderer: Add ply_renderer_get_keymap function
  * terminal: add ply_terminal_get_keymap function
  * key-file: Add support for non ini style config files
  * x11-render-plugin: Use GTK 3.22's method to get screen size to avoid deprecate warning in compile.
  * space-flares: Fix compiler warning
  * ply-utils: Drop unused ply_string_has_prefix helper
  * main: Use ply_kernel_command_line_get_key_value where appropriate
  * ply-utils: Add ply_kernel_command_line_get_key_value helper
  * two-step: Merge show_password_prompt and show_prompt into 1 function
  * twp-step: Remove superflous is_hidden / is_stopped checks from on_draw
  * two-step: Cleanup stop_animation function
  * two-step: Group progress_animaton init together with creation
  * themes: Move spinifity from the throbgress splash to the two-step splash
  * two-step: Add new UseAnimation setting
  * two-step: Make progress-bar location and size configurable
  * two-step: Fix progress-bar not hiding when it should
  * two-step: Fix progress-bar not updating on normal boot
  * two-step: Fold ply_progress_animation_hide call into view_start_end_animation
  * two-step: Add a capslock indicator
  * two-step: Use new ply_key_file_get_* helpers to read theme file
  * libply: Add ply_key_file_get_long() function
  * libply: Add ply_key_file_get_double() function
  * libply: Add ply_key_file_get_raw_value() helper
  * libply-splash-graphics: Add new capslock-icon control
  * ply-renderer: Add ply_renderer_get_capslock_state function
  * terminal: add ply_terminal_get_capslock_state function
  * label: Properly deal with pixel-buffers with non-upright device_rotation
  * ply-device-manager: De-activate and close renderer on device hot unplug
  * script: Add image tile support.
  * plymouthd.defaults: Bump default DeviceTimeout to 8 seconds
  * Update tr.po
  * two-step: bgrt: Add workaround for desktops which do not use the golden ratio
  * Revert "Merge branch 'avoid_shutdown_failure_v2' into 'master'"
  * ply-utils: Drop ply_fd_can_take_data and ply_fd_may_block function Since it is from a bygone time which is no longer in use.
  * ply-utils: Get rid of unused old code, drop function ply_get_max_open_fds, ply_close_open_fds, ply_close_all_fds.
  * scripts: update file plymouth.spec to integrate recent fixes.
  * ply-systemd-units: Drop attach-session in systemd-units to avoid the failure of unmounting separate /var during poweroff.
  * two-step: Deal with buggy firmware which does not pre-rotate the bgrt image
  * Revert "Merge branch 'bugfix' into 'master'"
  * ply-utils: Drop ply_fd_can_take_data and ply_fd_may_block function Since it is from a bygone time which is no longer in use.
  * configure: bump so name
  * ply terminal session: Drop function ply_terminal_session_execute and ply_terminal_session_open_console, Since this is a feature from a bygone time which is no longer in use without ply_terminal_session_run.
  * ply terminal session: Drop ply_terminal_session_run, this is a feature from a bygone time which is no longer in use
  * Regenerate plymouth.pot
  * two-step: Add support for firmware-splashes with rotation status bits set
  * Unify all code's vi format control. Update several file's vi format control line to make it easy to maintain.
  * ply-text-display.c: Correct vi format line make vi can directly edit this file without errors and make it use 8 space tabs etc.
  * Add a new firmware-upgrade mode for use by fwupd
  * drm: Fix tiled mode detection
  * main.c: Deprecate gdm transition signal
  * themes: Update spinner and bgrt background settings
  * ply-pixel-buffer: Fix right and bottom edge rendering of scaled buffers
  * Add support for translating the user visible strings in some themes
  * Prefix Title and Subtitle theme config keywords with an underscore
  * Add new reboot and system-upgrade modes
  * main: Remove private ply_mode_t
  * two-step: Make ProgressBarShowPercentComplete a per mode setting
  * plymouthd.defaults: Change default ShowDelay to 0
  * ply-boot-splash: Do not add ply_boot_splash_update_progress timeout multiple times
  * logging: Minor log-message fixes
  * logging: Improve logging format
  * themes: Update spinner and bgrt theme offline updates mode
  * two-step: Add a per mode setting to suppress messages
  * two-step: Add progress-bar support
  * two-step: Add MessageBelowAnimation option
  * two-step: Add support for specifying a title and sub-title in the theme file
  * two-step: Add per mode settings
  * two-step: Drop background_is_bgrt view_t member
  * ply-progress-bar: Allow caller to specify the widgets width and height
  * ply-progress-bar: Allow choosing fore- and back-ground color
  * ply-progress-bar: Redraw on percentage update
  * ply-label: Make sure get_width_of_control / get_height_of_control return correct values
  * boot-server: fix type confusion when allocating connection object
  * ply-device-manager: Handle change events for monitor hotplugging
  * ply-device-manager: Consume all events in one go
  * drm: Stop limiting preferred-mode picking to UEFI systems
  * drm: Reset mode on display-port connected outputs with a bad link-status
  * drm: Implement handle_change_event
  * drm: Ensure heads are mapped before flushing them
  * drm: Allow calling create_heads_for_active_connectors multiple times
  * drm: Allow calling ply_renderer_head_add_connector with existing connector_id
  * drm: Limit backend->resources lifetime to within query_device
  * drm: Store and keep all the outputs in the backend
  * drm: Add get_output_info helper function
  * drm: Stop storing a pointer to drmModeConnector in ply_output_t
  * drm: Stop keeing a drmModeConnector instance around
  * drm: Refactor ply_renderer_head_add_connector and ply_renderer_head_new
  * ply-renderer: Add ply_renderer_handle_change_event function
  * ply-array: Add ply_array_contains_uint32_element function
  * themes: Update spinner and bgrt diskcrypt dialog
  * themes: spinner: Add watermark alignment settings
  * themes: bgrt: Remove duplicate images
  * plymouth-populate-initrd: Don't assume the ImageDir is the theme-dir
  * two-step: Make clearing the dialog-background when using the firmware background optional
  * two-step: Add support for non center alignment of the (diskcrypt) dialog
  * two-step: Make the box image surrounding the unlock dialog optional
  * two-step: Rename UseBGRT to UseFirmwareBackground
  * libply: Add ply_key_file_get_bool function
  * two-step: Use plymouth_strtod
  * libply: Add ply_strtod helper
  * ply-keyboard: Fix compiler warning
  * device-manager: free keyboards when deactivating a renderer
  * keyboard: add helper to get the keyboard's renderer, if applicable
  * drm: Pick a controller for unconfigured connectors
  * drm: Drop crtcs for clones for which we've picked different modes
  * drm: More connector enumeration refactoring
  * drm: Store tiled and rotation in ply_output_t
  * drm: Refactor create_heads_for_active_connectors
  * drm: Directly store the mode instead of the mode_index
  * drm: Drop unused encoder_id
  * two-step: Do not rotate bgrt background image for upside-down panels
  * themes: Add new BGRT theme, using the firmware boot splash as background
  * two-step: bgrt: Deal with quirky firmwares
  * two-step: Add ACPI BGRT extension support
  * two-step: Speed up background-tile drawing on HiDPI screens
  * two-step: Use a pixel-buffer instead of an image for the view's background
  * ply-pixel-display: Add ply_pixel_display_get_device_scale() function
  * ply-pixel-buffer: Add ply_pixel_buffer_rotate_upright helper
  * ply-pixel-buffer: Add ply_pixel_buffer_get/set_device_rotation helpers
  * ply-pixel-buffer: Fix marking buffers as opaque when doing a solid fill
  * ply-pixel-buffer: Fix fill_with_buffer fastpath when device_scale != 1
  * drm: Implement ply_renderer_get_panel_properties
  * ply-renderer: Add ply_renderer_get_panel_properties function
  * ply-image: Add support for loading BMPs
  * ply-image: Do not assume all files are PNGs
  * two-step: Fix crash asking for password with multiple heads
  * spinner theme: update
  * two-step: Fix animation not starting on later added heads
  * ply-device-manager: Fix race causing undesired creation of non-gfx devs
  * logger: Add a separator between different boot logs
  * systemd-units: Also add "ConditionVirtualization=!container" in systemd-ask-password-plymouth.path.in
  * configure: bump to 0.9.5
  * drm: Use preferred mode for outputs instead of current mode
  * drm: Refactor ply_renderer_connector_get_rotation
  * drm: Reset LUT/gamma table before the first drmModeSetCrtc call
  * libply: Move kernel commandline parsing functions to libply/ply-utils
  * throbber: Don't skip last frame when waiting for end.
  * boot-server: free the argument and triggers
  * script: fix various memory leaks
  * key-file: ply_key_file_get_value returns duplicated memory, don't leak
  * event-loop: fix leak in error path
  * boot-splash: fix memory leak in error path
  * populate-initrd: drop unused local variable
  * device-manager: don't watch for udev events when deactivated
  * main: ensure tty is closed on deactivate
* Fri May 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update plymouth.spec: Do not own /usr/share/locale (owned by filesystem):
  + Split out -lang package
  + Use find_lang macro to create file list for -lang package
* Wed Feb 24 2021 Cliff Zhao <qzhao@suse.com>
- Pickup plymouth-only_use_fb_for_cirrus_bochs.patch: Currently our
  kernel hardware support need this fix, and boo#1172028 will be
  fix seperately (bnc#888590 boo#1172028 bsc#1181913).
* Sat Feb 20 2021 Cliff Zhao <qzhao@suse.com>
- Disable plymouth-systemd-KillMode-mixed.patch: Temporary disable
  it, because aarch64 and ppc64le system could not booting in
  release period, and this is only a enhancement with no harm to
  rollback (bnc#1177082, bnc#1182145, bnc#1184087).
* Sat Feb 13 2021 Arjen de Korte <suse+build@de-korte.org>
- Fix broken use of %%service_add_post and %%service_del_postun. Without
  any services specified, the first is a no-op, the latter will only
  execute systemctl daemon-reload (boo#1179849).
- Use %%ldconfig_scriptlets macro in Tumbleweed
* Mon Feb  1 2021 Cliff Zhao <qzhao@suse.com>
- Disable plymouth-ignore-serial-console.patch:
  We could not totally disable serial, because S390 and some customer
  are still rely on it (bnc#1180973, bnc#1181216).
* Tue Dec  8 2020 Cliff Zhao <qzhao@suse.com>
- Update to version: 0.9.5+git20201026:
  Don't wait forever for a ping reply.
* Sat Nov 21 2020 Cliff Zhao <qzhao@suse.com>
- Add plymouth-disable-fedora-logo.patch:
  Disable the image link which point to the fedora logo. this
  modification will also avoid the failure report from build
  checker.
* Tue Oct 27 2020 Cliff Zhao <qzhao@suse.com>
- Add plymouth-ignore-serial-console.patch:
  Don't output in serial console for openQA need to take serial in
  the test, and yast-installation prgram has a feature to install
  system through it (bnc#1051692 bnc#1164123 bnc#1170906).
* Fri Oct 16 2020 Ludwig Nussel <lnussel@suse.de>
- Update plymouth.spec: prepare usrmerge (boo#1029961)
* Wed Oct  7 2020 Cliff Zhao <qzhao@suse.com>
- Update to version: 0.9.5+git20200921+20778f2:
  * boot-server: Handle client disconnecting while trigger pending.
  * boot-server: Ref count the connections.
  * drm: Honor modes selected by the user through video= kernel
    cmdline argument.
  * use resolution of higher res monitor for window size.
  * autogoo: use /proc/self/fd/0 instead of /dev/stdin.
  * main: Don't bail out of load_settings if "Theme" is missing.
  * main: switch log file when switching mode.
  * main: fix mode changing before splash is shown.
  * two-step: Center message text within labels if labels are
    centered.
  * drm/kms probe speedups.
  * drm: Do not unnecessarily get output info twice.
  * ply-device-manager: Only consume one udev event at a time.
  * two-step: Do not jump to end-animation on halt/reboot if it is
    disabled.
  * two-step: Add UseEndAnimation setting.
  * script: add Image.Crop(x, y, width, height).
  * ply-throbber: Do not redraw when we need to stop throbbing on
    free.
  * ply-keymap-icon: Do not draw on free.
  * ply-capslock-icon: Do not draw on free.
  * script: add missing unref() for system update func.
  * themes: Drop UseFirmwareBackground=true from spinner/bgrt
    firmware-upgrade settings.
  * Fix SetSystemUpdateFunction.
  * event-loop: Remove ply_trace calls around the disconnect handler.
  * ply-terminal-session: Not use grantpt when the system shut down.
    to avoid sytem hung up.
  * build-goo: Remove vestigial remnants of old GDM integration code.
- Drop plymouth-avoid-umount-hanging-shutdown.patch: because has
  been merged to upstream.
* Mon Sep 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove gnu-unifont-bitmap-fonts runtime dependency, it is not
  used anywhere.
- Remove unused kernel-headers and module-init-tools build deps.
- Make plymouth-scripts noarch, correct its runtime dependencies.
- Clean up spec file.
* Sat Aug 29 2020 Cliff Zhao <qzhao@suse.com>
- Add plymouth-no-longer-modify-conf-to-drop-isopensuse-macro.patch:
  plymouth will use plymouthd.defaults instead of plymouth.conf and
  packge plymouthd.defaults in a seperet RPM. this can avoid change
  SUSE or openSUSE branding section with is_opensuse macro in the
  config file. means this modification can close the leaps gap
  (jsc#SLE-11637).
* Fri Aug 28 2020 Cliff Zhao <qzhao@suse.com>
- Update plymouth.spec: Dropping gdm transition because it has
  alreay deprecated by upstream. Removing git build dependency.
* Mon Jun 15 2020 Cliff Zhao <qzhao@suse.com>
- Drop plymouth-only_use_fb_for_cirrus_bochs.patch: openSUSE user
  are using emu-5.0.0 on MacOS-X with HVF acceleration, the
  Plymouth theme with script module fails to go to graphic mode
  with this patch(boo#1172028).
* Wed Oct 30 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Avoid inconsistencies in library package names causing unresolvable
  dependencies, replace all soversion occurences with a macro.
* Wed Sep 11 2019 Cliff Zhao <qzhao@suse.com>
- Add patch plymouth-avoid-umount-hanging-shutdown.patch:
  To avoid grantpt() call nsslookup, it will hanging system unmount
  /var during shutdown period(bnc#1105688, bnc#1129386,
  bnc#1134660, bnc#1166601, bnc#1171971).
* Thu Aug 15 2019 Cliff Zhao <qzhao@suse.com>
- Update to version 0.9.5+git20190908+3abfab2:
  * two-step: Deal with buggy firmware which does not pre-rotate the bgrt image
  * configure: bump so name
  * Internationalization: Add zh_HK and zh_TW translations.
  * add delay time to 8 seconds to fit AMD graphic card.
* Mon Aug  5 2019 Cliff Zhao <qzhao@suse.com>
- Update plymouth.spec: Disable upstart-monitor compile because it
  only used in Ubuntu/Debian.
* Sun Aug  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update plymouth.spec: Use bcond_with for X11 renderer, cleanup
  syntax.
* Wed Jul 31 2019 Cliff Zhao <qzhao@suse.com>
- Update plymouth.spec: obsolete plymouth render plugin for
  Xwindows, Since this plugin will not be used in the production
  environment, and this modify will highly decrease the compilation
  of build requirements.
* Mon Jul  8 2019 Cliff Zhao <qzhao@suse.com>
- Update to version 0.9.4+git20190612+9359382:
  * two-step: Add support for firmware-splashes with rotation
    status bits set
  * Regenerate plymouth.pot to add the strings for the new
    firmware-upgrade mode.
* Fri Jun 14 2019 Cliff Zhao <qzhao@suse.com>
- Add dependency to dracut for plymouth-scripts(bnc#1138248).
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Tue Apr  2 2019 Stasiek Michalski <hellcp@mailbox.org>
- Change default openSUSE theme to bgrt
* Wed Mar 27 2019 Cliff Zhao <qzhao@suse.com>
- Update to version 0.9.4+git20190325+b9f2aac:
  * themes: Update spinner and bgrt background settings
  * Translations: Sync translations with zanata
* Sun Mar 24 2019 Stasiek Michalski <hellcp@mailbox.org>
- Fix theme-bgrt dependencies
  (based on plugin-two-step with images from theme-spinner)
* Tue Mar 12 2019 qzhao@suse.com
- Update to version 0.9.4+git20181219.c8f1256:
  * ply-pixel-buffer: Fix right and bottom edge rendering of
    scaled buffers.
  * Add support for translating the user visible strings in some
    themes
  * Prefix Title and Subtitle theme config keywords with an
    underscore
  * Add new reboot and system-upgrade modes
  * main: Remove private ply_mode_t
  * two-step: Make ProgressBarShowPercentComplete a per mode
    setting
  * plymouthd.defaults: Change default ShowDelay to 0
  * ply-boot-splash: Do not add ply_boot_splash_update_progress
    timeout multiple times
  * logging: Minor log-message fixes.
    Improve logging format.
  * themes: Update spinner and bgrt theme offline updates mode
  * two-step: Add a per mode setting to suppress messages.
    Add progress-bar support.
    Add MessageBelowAnimation option.
    Add per mode settings.
    Drop background_is_bgrt view_t member
  * ply-progress-bar: Allow caller to specify the widgets width and
    height.
    Allow choosing fore- and back-ground color.
    Redraw on percentage update.
  * boot-server: fix type confusion when allocating connection object
  * ply-device-manager: Handle change events for monitor hotplugging.
    Consume all events in one go.
  * drm: Stop limiting preferred-mode picking to UEFI systems.
    Reset mode on display-port connected outputs with a bad
    link-status.
    Implement handle_change_event.
    Ensure heads are mapped before flushing them.
    Allow calling create_heads_for_active_connectors multiple
    times.
    Allow calling ply_renderer_head_add_connector with existing
    connector_id.
    Limit backend->resources lifetime to within query_device.
    Store and keep all the outputs in the backend.
    Add get_output_info helper function
    Stop storing a pointer to drmModeConnector in ply_output_t
    Stop keeing a drmModeConnector instance around.
    Refactor ply_renderer_head_add_connector and
    ply_renderer_head_new
- Rebase 0002-Install-label-ft-plugin-into-initrd-if-available.patch
* Wed Jan  2 2019 qzhao@suse.com
- Update to version 0.9.4+git20181219.c8f1256:
  * two-step: Use plymouth_strtod
    Use the locale agnostic plymouth_strtod helper which always
    uses a "." as decimal seperator. This fixes the various
    Alignment options not working with some locales.
* Wed Dec 12 2018 qzhao@suse.com
- Update to version 0.9.4+git20181209.f7d5bb1:
  * ply-keyboard: Fix compiler warning
  * When a renderer goes away on a udev remove event, free
    keyboards associated with the renderer, before freeing the
    renderer.
  * device-manager: free keyboards when deactivating a renderer
  * keyboard: add helper to get the keyboard's renderer, if
    applicable.
* Wed Dec  5 2018 qzhao@suse.com
- Update to version 0.9.4+git20181204.0cd0613:
  * drm: Pick a controller for unconfigured connectors
  * drm: Drop crtcs for clones for which we've picked different
    modes
  * drm: More connector enumeration refactoring
  * drm: Store tiled and rotation in ply_output_t
  * drm: Refactor create_heads_for_active_connectors
  * drm: Directly store the mode instead of the mode_index
  * drm: Drop unused encoder_id
* Thu Nov 29 2018 qzhao@suse.com
- Update to version 0.9.4+git20181129.a7ec3e6:
  * Add new BGRT theme, using the firmware boot splash as background
  * two-step: bgrt: Deal with quirky firmwares, Add ACPI BGRT
  extension support, Speed up background-tile drawing on HiDPI
  screens, Use a pixel-buffer instead of an image for the view's
  background
  * ply-pixel-buffer: Add ply_pixel_buffer_rotate_upright helper,
  Add ply_pixel_buffer_get/set_device_rotation helpers, Fix marking
  buffers as opaque when doing a solid fill, Fix fill_with_buffer
  fastpath when device_scale != 1.
* Fri Nov 23 2018 qzhao@suse.com
- Update to version 0.9.4+git20181122.aaa140b:
  Add a separator between different boot logs
  Fix race causing undesired creation of non-gfx devs
  Fix animation not starting on later added heads
* Mon Nov 12 2018 qzhao@suse.com
- Update to version 0.9.4+git20181111.118c5ca:
  Modify systemd-units: Add "ConditionVirtualization=!container" in
  all plymouth-*.service, also systemd-ask-password-plymouth.path.
* Tue Nov  6 2018 qzhao@suse.com
- Update to version 0.9.4+git20181105.f898586:
  bump to 0.9.4
* Wed Oct 31 2018 qzhao@suse.com
- Update to version 0.9.3+git20181031.025ce59:
  drm: use preferred mode for outputs
  drm: Refactor ply_renderer_connector_get_rotation
  drm: Reset LUT/gamma table before the first drmModeSetCrtc call
  libply: Move kernel commandline parsing functions to libply/ply-utils
  throbber: Don't skip last frame when waiting for end.
- Drop plymouth-throbber-Don-t-skip-last-frame-when-waiting-for-end.patch
  * Upstream has already accept Michal's modification.
* Tue Oct 23 2018 msrb@suse.com
- plymouth-throbber-Don-t-skip-last-frame-when-waiting-for-end.patch
  * Make sure plymouthd stops throbber animation at the first
    opportunity after receiving quit command, instead of looping
    multiple times. (boo#1110199)
* Thu Oct 18 2018 qzhao@suse.com
- Update to version 0.9.3+git20180827.0a66272:
  * boot-server: free the argument and triggers
  * event-loop: fix leak in error path
  * script: fix various memory leaks
  * key-file: ply_key_file_get_value returns duplicated memory, fix
    memory leaks.
  * event-loop: fix leak in error path
  * boot-splash: fix memory leak in error path
  * populate-initrd: drop unused local variable
* Tue Aug 28 2018 qzhao@suse.com
- Update to version 0.9.3+git20180827.0a66272:
  ensure tty is closed on deactivate
  If plymouth doesn't get explicitly "activated" then when
  GDM tries to deactivate it, the deactivation request is
  a noop.
  One aspect of being active, though is having ownership and
  control of the terminal.  This happens immediately, even
  before a splash is shown.
  The `deactivate` request needs to relinguish such control,
  unconditionally, since some display server is about to use
  the tty.
- Update patch name base on quilt standerd
  Remove only_use_fb_for_cirrus_bochs.patch
  Add plymouth-only_use_fb_for_cirrus_bochs.patch
  Remove 0001-Some-greenish-openSUSE-colors.patch
  Add plymouth-some-greenish-openSUSE-colors.patch
* Fri Aug 17 2018 bjorn.lie@gmail.com
- Update to version 0.9.3+git20180807.7663b0c:
  * systemd-units: Add "ConditionVirtualization=!container"
  * README: add link to Code of Conduct
  * two-step: add unhandled splash mode case to switch
  * main: fix build
  * Fix miscellaneous compiler warnings
  * configure: Pass -Wno-cast-function-type if available
  * main: Fix getting detailed logs from systemd
  * main: Show details when ESC is pressed during splash_delay
  * drm: Remove unnecessary reset_scan_out_buffer_if_needed() call
    from ply_renderer_head_map()
  * main: Only activate renderers if the splash uses pixel-displays
- Switch to new gitlab home in _service.
- Refresh patches with quilt.
- Use autosetup macro.
* Sat Aug  4 2018 qzhao@suse.com
- Drop plymouth-fix-window-size: The use of the smallest screen
  size is deliberate (boo#804607 bsc#894051).
* Wed Apr 11 2018 oholecek@suse.com
- Modify 0001-Add-label-ft-plugin.patch to fix problems with
  multiline text (bsc#1083695)
  * to prevent infinite loop newline characters need to be skipped
- Use %%license instead of %%doc (bsc#1082318)
* Sat Jan 13 2018 zaitor@opensuse.org
- Update to version 0.9.3+git20171220.6e9e95d:
  * device-manager: drop superfluous
    create_pixel_displays_for_renderer call
  * x11: don't call gdk_display_get_name before gtk_init
* Mon Dec  4 2017 zaitor@opensuse.org
- Update to version 0.9.3+git20171130.fa66a5b:
  * INSTALL: Fix a spelling error in the command example
  * populate-initrd: handle themes with subdirs
  * device-manager: fall back to text mode if graphical devices
    fail
  * scripts: Use >&2 instead of /dev/stderr
  * terminal: add include for sysmacros.h
  * configure: bump to 0.9.4
  * terminal-session: don't delete boot.log
  * Revert "Make boot.log world readable by default"
- Rebase 0002-Install-label-ft-plugin-into-initrd-if-available.patch
* Wed Nov 29 2017 qzhao@suse.com
- Drop stop-graphical.patch: There are no conflicting these days,
  obsolete this patch to enable auto switch to TTY when display
  server not exist (boo#1066510).
* Wed Jun 14 2017 qzhao@suse.com
- Update plymouth.spec: Add COPYING file in plymouth package file
  list, This is for the law requirement (bsc#1043834).
* Mon May  8 2017 antoine.belvire@opensuse.org
- Update to version 0.9.2+git20170424.6fd5c6b:
  * main: Look for config in runtime dir first
  * main: Look for theme in runtime dir first
  * Revert "Recreate boot log at each boot instead of appending"
  * x11: implement get_display_name
  * drm: implement get_display_name
  * configure: don't look for libudev when --without-udev is passed
  * renderer: export device name from plugin
  * device-manager: handle NULL renderer better
- Remove 0001-device-manager-handle-NULL-renderer-better.patch
  (upstreamed).
* Thu Jan 26 2017 zaitor@opensuse.org
- Drop use-mkinitrd.patch: No longer needed, mkinitrd is just a
  wrapper for dracut now any way, hence this patch is currently
  pointless.
* Wed Jan 25 2017 fvogt@suse.com
- Remove patch which causes breakage with systemd-vconsole-setup (bsc#1020327):
  * 0001-let-it-become-a-real-daemon.patch
- Add upstream patch to fix crash on boot:
  * 0001-device-manager-handle-NULL-renderer-better.patch
- Replace removal of framebuffer driver and plymouth-ignore-cirrusdrm.patch
  with single patch:
  * only_use_fb_for_cirrus_bochs.patch
* Mon Jan  9 2017 zaitor@opensuse.org
- Update to version 0.9.2+git20161215.18dd755:
  * terminal: refresh geometry after drm device arrives
  * logger: stop using carriage returns
  * build-goo: don't install systemd units during distcheck
  * systemd-units: Fix uninstall script
  * configure: switch to tar.xz instead tar.bz2
  * libply: fix HiDPI detection
  * libply, main: Add device scale setting
  * main: support plymouth.force-scale on the kernel command line
  * build-goo: make udev support build time optional
  * device-manager: dont pass terminal as renderer device
* Tue Sep  6 2016 tchvatal@suse.com
- Update to version 0.9.2+git20160823.e4b7e49:
  * libply: fix HiDPI detection
  * libply, main: Add device scale setting
  * main: support plymouth.force-scale on the kernel command line
- Refresh patch:
  * 0001-let-it-become-a-real-daemon.patch
* Tue Sep  6 2016 tchvatal@suse.com
- Add systemd to buildrequires to properly detect systemd-ask-password
* Thu Aug  4 2016 tchvatal@suse.com
- Sort out with spec-cleaner and move all buildrequires to main scope
  not to subpkgs, sometimes interpreted wrongly by rpm if it is split
* Thu Aug  4 2016 tchvatal@suse.com
- Reduce patches list removing merged upstream (bit differently tho):
  * 0001-seats-guard-against-NULL-terminal.patch
  * fix-serial-consoles.patch
  * plymouth-boot-vga-framebuffer.patch
- Refresh patches:
  * 0001-let-it-become-a-real-daemon.patch
- Update to version 0.9.2+git20160620.0e65b86:
  * configure: tweak defaults to be more systemd friendly
  * text: don't draw if not animating
  * terminal: always open terminal in non-blocking mode
  * device-manager: probe existing DRM devices at startup
  * drm: don't pick up drm master implicitly
  * terminal: refresh geometry after drm device arrives
  * logger: stop using carriage returns
  * build-goo: don't install systemd units during distcheck
  * systemd-units: Fix uninstall script
  * configure: switch to tar.xz instead tar.bz2
* Wed Jun  1 2016 idonmez@suse.com
- Remove framebuffer support bsc#980750 and bsc#982226
* Mon Feb  8 2016 fvogt@suse.com
- Add 0003-fix_null_deref.patch as well
  - Avoid potential SEGV if label plugin fails to load
* Wed Jan 20 2016 fvogt@suse.com
- Add 0001-Add-label-ft-plugin.patch and
    0002-Install-label-ft-plugin-into-initrd-if-available.patch:
  - Ability to output text in initrd, needed for encryption
  - boo#959986
* Mon Dec 28 2015 dimstar@opensuse.org
- Update to version 0.9.2:
  + two-step: Add separate startup / shutdown animations.
  + device-manager: try fb device if drm device failed.
  + Port to GTK+ 3.0.
  + script support system update events.
  + Drop the obsolete log-viewer
- Rebase patches:
  + plymouth-fix-window-size
  + stop-graphical.patch
  + 0001-Some-greenish-openSUSE-colors.patch
  + fix-serial-consoles.patch
  + 0001-seats-guard-against-NULL-terminal.patch
  + plymouth-ignore-cirrusdrm.patch
  + plymouth-boot-vga-framebuffer.patch
  + 0001-let-it-become-a-real-daemon.patch
- Drop upstream fixed patches:
  + 0001-device-manager-only-call-ply_terminal_free.patch
  + 0001-splash-remove-pixel_pixel-in-sprite-lib-when-notifie.patch
  + 0001-splash-do-not-process-display-lists-if-it-is-empty.patch
  + 0001-libply-splash-core-also-monitor-for-file-removal-in-.patch
  + 0001-seat-be-a-little-more-forgiving-in-the-case-there-s-.patch
  + 0001-text-step-bar-use-correct-utf-8-multibyte-sequence-f.patch
- Replace pkgconfig(gtk+-2.0) BuildRequires with
  pkgconfig(gtk+-3.0), following upstreams port to GTK+ 3.0.
- Rename library subpackage from *2 to *4, followings upstreams
  soname bump.
- Drop utils subpackage: the log-viewer, which was the only tool
  left, has been dropped.
* Thu Dec 10 2015 tiwai@suse.de
- Fix missing dependency on coreutils for initrd macros (boo#958562)
- Call missing initrd macro at postun (boo#958562)
* Mon Sep 21 2015 idonmez@suse.com
- Use is_opensuse to simplify if/else block
* Fri Sep  4 2015 idonmez@suse.com
- Add a direct dependency on systemd, since we need to know the
  path to systemd-tty-ask-password-agent, fixes part of bsc#943312
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Thu Sep 25 2014 idonmez@suse.com
- Update 0001-let-it-become-a-real-daemon.patch to call setsid
  only from the child process.
* Fri Sep 12 2014 idonmez@suse.com
- Add 0001-let-it-become-a-real-daemon.patch to make plymouth
  a real daemon, fixes part of bnc#889757. Patch by Werner.
* Thu Sep  4 2014 idonmez@suse.com
- Add plymouth-boot-vga-framebuffer.patch to fix boot_vga
  problem with framebuffer devices. (bnc#886211)
* Mon Aug 11 2014 idonmez@suse.com
- Modify plymouth-ignore-cirrusdrm.patch to return as
  early as possible. Patch by glin@suse.com
* Thu Aug  7 2014 idonmez@suse.com
- Invert the logic in plymouth-ignore-cirrusdrm.patch bnc#890516
* Mon Jul 28 2014 fcrozat@suse.com
- Add
  0001-text-step-bar-use-correct-utf-8-multibyte-sequence-f.patch:
  fix incorrect UTF-8 code used for square (bnc#886148).
* Fri Jul 25 2014 fcrozat@suse.com
- Add plymouth-ignore-cirrusdrm.patch: ignore cirrus drm and use fb
  instead (bnc#888590)
* Thu Jul 24 2014 fcrozat@suse.com
- Add
  0001-seat-be-a-little-more-forgiving-in-the-case-there-s-.patch:
  Be more forgiving with empty seat.
* Tue Jul  8 2014 fcrozat@suse.com
- Update 0001-Some-greenish-openSUSE-colors.patch to also use SUSE
  colors on tribar (bnc#886148)
* Fri Jun 27 2014 fcrozat@suse.com
- Add
  0001-libply-splash-core-also-monitor-for-file-removal-in-.patch:
  handle new udev behaviour in seqnum removal.
* Fri Jun 20 2014 fcrozat@suse.com
- Add
  0001-splash-do-not-process-display-lists-if-it-is-empty.patch:
  fix crash when calling plymouth quit
- Add 0001-seats-guard-against-NULL-terminal.patch: guard against
  NULL terminal.
- Update stop-graphical.patch: add RemainAfterExit=true to
  plymouth-start.service, ensuring plymouthd is not restarted when
  switching between runlevels.
* Thu Jun 19 2014 fcrozat@suse.com
- Add
  0001-splash-remove-pixel_pixel-in-sprite-lib-when-notifie.patch:
  fix crash when pixel_display is removed.
- Add 0001-device-manager-only-call-ply_terminal_free.patch: fix
  crash.
- Add use-mkinitrd.patch: call mkinitrd -B, not dracut for now,
  otherwise initramfs is being created by plymouth-update-initrd,
  not initrd file.
- Ensure we don't rebuild initrd twice when updating plymouth.
- Ensure default theme is SLE/openSUSE (based on %%suse_version)
* Fri Jun  6 2014 fcrozat@suse.com
- Release 0.9.0 (3 additional fixes compared to previously packaged
  git snapshot):
  + Use udev for graphics device enumeration
  + Add new text plugin to replace the tribar one
  + Add background tiling and watermark support to two-step
  + Make various plymouth commands that change state be resilient
    to being  called multiple times
  + Support going back to the initrd at shutdown
  + Keyfile parser improvements
  + Make plymouthd use better defaults when running on top of X11
  + Fixes for systems using QXL
  + minor two-step plugin fixes
  + Use /sys/class/tty/console/active instead of parsing
    /proc/cmdline for consoles.
  + Documentation improvements
  + Drop driver specific renderers and use generic driver across the
    board.
  + Better debug message output
  + systemd integration fixes
  + upstart integration fixes
  + initrd scripts fixes
  + Misc fixes
* Thu Jun  5 2014 idonmez@suse.com
- Update fix-serial-consoles.patch to fix a crash in some rare
  cases.
* Wed May 21 2014 idonmez@suse.com
- Add fix-serial-consoles.patch to fix binary garbage on serial
  consoles. This is bnc#873859
* Mon May  5 2014 fcrozat@suse.com
- Remove plymouth-restore-suspend.patch: suspend package is being
  dropped, no longer needs to provide this old API.
- Remove requires on suspend package.
* Thu Apr 17 2014 idonmez@suse.com
- Update to git snapshot as of 20140327
  * Fixes bnc#872502 and bnc#872428
* Wed Apr 16 2014 trenn@suse.de
- Kill all mkinitrd stuff
  Remove suse-initrd-support
- Tell zypper to regenerate initrd on installation/update via %%post and
  %%posttrans scripts
* Thu Apr 10 2014 idonmez@suse.com
- Add plymouth-manpages.patch to fix manpage installation (bnc#871419)
* Thu Feb 20 2014 fcrozat@suse.com
- Drop plymouth.conf, it is no longer used, plymouthd.conf is
  nowadays.
* Sat Feb 15 2014 kigurame@opensuse.org
- Updated from git
- carried over patches
- Dropped 0001-Make-plymouthd-real-daemon-and-save-old-log.patch
  Because it is really not necesary
* Wed Feb 12 2014 werner@suse.de
- Add patch
  0001-Make-plymouthd-real-daemon-and-save-old-log.patch
  all daemons should call setsid(2) to become a real daemons without
  controlling terminal.  Beside this the old boot log will help for
  debugging and for support.
* Thu Dec 12 2013 uweigand@de.ibm.com
- Add powerpc64le-linux support.
* Thu Sep 26 2013 lnussel@suse.de
- disable plymouth in initrd if the root volume is encrypted. This
  is a workaround until plymouth is able to handle the prompt
  correctly (bnc#834063).
* Wed Sep 11 2013 crrodriguez@opensuse.org
- version 0.8.8_git201309032142
- All device specific code has been removed because the kernel
  has been fixed in the meanwhile so plymouth no longer requires
  libdrm_intel, libdrm_radeon, libdrm_nouveau and can use the generic
  interface.
  This commit does not add any new features or bugfixes but removes
  a huge chunk of unnecessary code.
* Fri Aug 16 2013 lmuelle@suse.com
- Pre require plymouth from plymouth-scripts; (bnc#806388).
* Thu Aug  1 2013 tittiatcoke@gmail.com
- Update to version 0.8.8_git201308011340
  - Drop patch plymouth-correct-systemd-prefix.patch
  - Drop patch plymouth-close.patch
  - Drop patch plymouth-close-unredirect.patch
  - Drop patch plymouth-redirect-null.patch
  - Drop patch plymouth-exit-code.patch
  - Drop patch plymouth-terminal-session-close.patch
* Mon Jul 29 2013 tittiatcoke@gmail.com
- Add upstream patch plymouth-correct-systemd-prefix.patch to
  correct the systemd prefixes in some systemd files. This replaces
  the sed string.
* Thu Jun 27 2013 crrodriguez@opensuse.org
- Require pigz instead of gzip
- ensure plugin requires are versioned.
* Sun Jun 16 2013 crrodriguez@opensuse.org
- own %%{_localstatedir}/log/boot.log
  and %%{_localstatedir}/spool/plymouth/boot.log (as %%ghost s)
* Tue Jun 11 2013 fcrozat@suse.com
- Add plymouth-close: do not try to close negative fd.
- Add plymouth-close-unredirect.patch: do not leak fd when stopping
  redirection of /dev/console (bnc#811185)
- Add plymouth-redirect-null.patch: redirect plymouth standard io
  to /dev/null (bnc#811185)
- Add plymouth-exit-code.patch: ignore exit code in ExecStartPost.
- Add plymouth-terminal-session-close.patch: do no try to close
  terminal session fd if already closed.
* Sun May 12 2013 crrodriguez@opensuse.org
- Not only reboot.service is prefixed with systemd- currently
  but also kexec,halt,poweroff.
* Mon Apr 22 2013 crrodriguez@opensuse.org
- Also ensure we express rpm dependencies correctly
  this package is not gonna work on systemd < 186.
* Mon Apr 22 2013 crrodriguez@opensuse.org
- Update to version 0.8.8_git201304161248
- drop plymouth-change-service-name.patch, replaced by
  a sed script that will account for all service files' future changes
- drop patch plymouth-trace-lines, in upstream now
- drop plymouth-udevadm-path.patch, generic solution in upstream now.
- drop ply-sdunitdir.patch likewise.
- drop plymouth-systemd-in-usr.patch likewise.
- drop systemd-no-warning.patch, not needed with newer systemd
- drop plymouth-sd-notforking.patch , not really needed anymore.
* Thu Feb 28 2013 tittiatcoke@gmail.com
- Changed %%post scripts so only the rebuild of the initrd is
  omitted within the build environment
* Fri Feb 22 2013 tittiatcoke@gmail.com
- Added patch plymouth-correct-runtime-dir.patch to make the
  plymouthruntimedir equal to /run/plymouth and not /var/run/plymouth
* Wed Feb  6 2013 fcrozat@suse.com
- Rename plymouth-sd-notforking.patch to fix typo in patch name
- Add plymouth-change-service-name.patch: fix incorrect service
  names used for dependencies. Now use systemd-reboot.service
  (replacing reboot.service) and display-manager.service (replacing
  prefdm.service).
* Tue Dec 18 2012 tittiatcoke@gmail.com
- Make sure that the right version of the scripts is required by
  the main package. This to prevent that an update of the scripts
  is not installed (bnc#793400)
- Removed obsolete patch plymouth-remove-pid-file.patch. Issue
  has been resolved upstream
* Wed Nov 14 2012 seife+obs@b1-systems.com
- fix path to systemd-tty-ask-password-agent for newer systemd
- create the pid file again during boot, the existence of this is
  a condition for systemd-ask-password-plymouth.service. A proper
  fix might look different but that get's it going again.
* Tue Nov  6 2012 tittiatcoke@gmail.com
- Provide the scripts to integrate Plymouth in dracut as a
  separate package.
- Added patch (plymouth-dracut-path.patch) to correct the paths
  inside the specific plymouth-dracut scripts
* Mon Nov  5 2012 crrodriguez@opensuse.org
- Update to an slightly newer git snapshot to fix regression
  from 0.8.8
* Thu Nov  1 2012 crrodriguez@opensuse.org
- Version 0.8.8
  * main: Try to own socket before anything else
  * main: silently succeed if plymouthd is started a second time
  * service: start plymouthd unconditionally
  * x11: make window fullscreen by default
  * x11: only create windows when necessary
* Thu Nov  1 2012 crrodriguez@opensuse.org
- plymoith-sd-notforking.patch: Make plymouthd to not use
  Service type "forking"
- ply-sdunitdir.patch: Must install units in %%{_unitdir} as
  returned by pkg-config not in a hardcoded location.
* Fri Oct 12 2012 tittiatcoke@gmail.com
- Remove the non required font file in /etc/fonts/conf.avail/ .
* Thu Oct 11 2012 tittiatcoke@gmail.com
- Adjusted the upstream patch to remove the pid file. The original
  one seems to cause issues with the DM killing plymouth
* Thu Oct 11 2012 tittiatcoke@gmail.com
- Fix the Pango installation within the initrd. This would
  resolve the error message that Pango cannot find any fonts
* Thu Sep 27 2012 tittiatcoke@gmail.com
- fix the libdir path in plymouth-set-default-theme (bnc#780085)
* Thu Sep 20 2012 tittiatcoke@gmail.com
- Update to version 0.8.7
  + fix plymouth race at bootup breaking efi/vesa handoff
  + Systemd fixes
- Add plymouth-remove-pid-file.patch: remove PID file usage
  (bnc#780976) (Thanks to fcrozat)
- Remove upstream patches: plymouth-systemd-target.patch,
  0001-ply-text-progress-bar-strip-quotes-if-present,patch,
  plymouth-fix-systemd-service.patch, plymouth-after-udev-settle
  due to upstream inclusion.
* Wed Aug 22 2012 fcrozat@suse.com
- Add plymouth-after-udev-settle.patch: ensure plymouth is started
  after udev triggers has been started (git + name change due to
  systemd < 183 in openSUSE 12.2).
* Wed Aug 22 2012 tittiatcoke@gmail.com
- Ensure that the right Pango version is used for copying one of
  the pango modules
* Wed Aug  8 2012 fcrozat@suse.com
- Add plymouth-fix-systemd-service.patch: remove dashes next to
  semi-colons, it confuses systemd. (bnc#774400)
- Update suse-initrd-support to not start plymouth if kernel
  cmdline contains "shell" or "plymouth.enable=0" or
  "rd.plymouth=0".
* Mon Aug  6 2012 dmueller@suse.com
- remove suspend dependency on ARM
* Sun Jul 29 2012 jengelh@inai.de
- Ship /etc/os-release in the initrd so that the pretty name is
  displayed in text-splash mode
- Give the text-splash some SUSE-typical green coloring
* Sun Jul 29 2012 dmueller@suse.com
- fix build for ARM
* Thu Jul 26 2012 tittiatcoke@gmail.com
- Move the openSUSE branding to its rightful place
* Fri Jul 20 2012 fcrozat@suse.com
- Update to 0.8.6.1:
  + Fix systemd path file generation
- Changes from 0.8.6:
  + fix flush_area fast-path
  + seed random number generator by default for script plugins
  + allow plymouth to be built without gtk dependency
  + cope with lack of /etc/os-release better
  + pull in systemd unit files (bnc#770890)
  + add support for new "updates" mode for doing package updates
  (only available for some plugins at the moment)
- Add plymouth-restore-suspend.patch: revert commit removing
  suspend/resume support, needed for suspend package.
- Add plymouth-systemd-target.patch: add missing symlinks to start
  plymouth on shutdown / reboot / kexec (bnc#770764).
- Add plymouth-udevadm-path.patch: adapt to udevadm path on
  openSUSE.
- Ensure systemctl daemon-reload is called in post / postun
- Add systemd-no-warning.patch: remove Documentation tag not
  handled by systemd v44.
- Update stop-graphical.patch to correct prevent plymouth.quit to
  start under runlevel 5 (handled by xdm initscript directly).
* Fri Jul  6 2012 dvaleev@suse.com
- don't require intel_drm on ppc
* Wed Jul  4 2012 meissner@suse.com
- run "/sbin/mkinitrd" and let it figure out by itself
  what initrds to update. bnc#769812
* Mon Jul  2 2012 fcrozat@suse.com
- Provides systemd units, instead of relying on systemd to ship
  them (bnc#769397).
- Ensure plymouth--wait-quit.service conflicts with
  graphical.target.
* Fri Jun 29 2012 tittiatcoke@gmail.com
- Update to 0.8.5.1
  + two-step splash plugin quit fixes
  + add generic driver to drm renderer plugin
    This allows new modesetting drivers to work with plymouth
    automatically
  + fixes for video cards that don't support 32bpp
  + add alignment and width features to label controls
  + new documentation
  + event loop fix
  + more serial console fixes
  + better systemd integration
  + new flush api to client library
  + Allow plymouth to build the drm renderer without the driver
    dependent libdrm_* libraries.
* Thu Jun 21 2012 lnussel@suse.de
- disable plymouth if init is not systemd (could be e.g. /bin/sh or
  sysvinit then)
* Mon Jun 11 2012 coolo@suse.com
- if we provide bootsplash, we should also make sure to obsolete
  its version
* Mon Jun  4 2012 tittiatcoke@gmail.com
- Ensure that the openSUSE theme is default. (bnc#765277)
- Remove unnecessary changes to the kernel options. Plymouth also
  accepts splash=silent.
* Wed May 30 2012 vuntz@opensuse.org
- Add plymouth-scripts Requires(post) to branding-openSUSE
  subpackage, to make sure that the %%post scriptlet will work.
- Make sure we export LIB and not lib in the %%postun scriptlets of
  theme-solar and branding-openSUSE subpackages.
* Tue May 29 2012 tittiatcoke@gmail.com
- Ensure that label.so is being installed for the openSUSE branding
  (bnc#763574)
* Mon May 21 2012 tittiatcoke@gmail.com
- Update the installation/update from plymouth in a way that the
  initrd file for the current running kernel is updated.
- Corrected a typo with regards to the location of a pango module
  when setting up the initrd.
* Tue May 15 2012 tittiatcoke@gmail.com
- Added a patch for openSUSE to enable the rebuild of the initrd
  with the plymouth-set-default-theme script. (bnc#757284)
* Sun May 13 2012 tittiatcoke@gmail.com
- Added plymouth to the requires of plymouth-scripts. This
  should resolve bug (bnc#757284)
* Fri May 11 2012 nmo.marques@gmail.com
- Split x11 renderer into his own package; the x11 renderer allows
  users to test plymouth themes; having it available on the devel
  package will force people who just want to test a theme to
  install a lot of unwanted dependencies. Being on it's own package
  without explicit dependencies provides extra functionality to
  users who want to test themes without having to rebuild initrd
  and rebooting for testing.
- bnc#761403
* Sat Apr 28 2012 tittiatcoke@gmail.com
- Reduce the number of fonts that are included in the initrd. Also
  let mkinitrd sort out the dependencies for the required libs.
- Use the same font as that grub2 is currently using for it's
  graphics mode.
* Tue Apr 17 2012 glin@suse.com
- Correct the theme name in the post install script of
  plymouth-branding-openSUSE
* Thu Apr  5 2012 tittiatcoke@gmail.com
- Updated the initrd patch to include the necessary files to have
  text support (e.g. LUKS passphrase question, etc)
- Temporarily added a openSUSE plymouth theme
  (plymouth-branding-openSUSE) to have a better integration with
  12.2.
* Thu Mar 29 2012 tittiatcoke@gmail.com
- Ensure that both grub and grub2 are adjusted with regards to the
  splash parameter. Running grub2-mkconfig to have the right
  configuration.
- Installation of themes are not causing any reset of the selected
  default theme anymore. Now this only happens when a theme is
  installed and the default theme is set to TEXT.
* Sun Mar 25 2012 tittiatcoke@gmail.com
- Update to the official release of 0.8.4
  * Bugfix:  Use /dev/fb0 instead of /dev/fb, this resolves the
    issue of not showing the splash during shutdown
* Fri Mar  9 2012 tittiatcoke@gmail.com
- Add a small change in order to have plymouth activated with Grub2
* Thu Feb 23 2012 tittiatcoke@gmail.com
- Make sure that the package libply-boot-client is always
  installed to prevent a system that will not boot
* Thu Feb 23 2012 saschpe@suse.de
- Replaced package core-libs with individual packages for each shared
  library (SLPP)
- Proper provides/obsoletes pair for bootsplash
- Could not resist to run spec-cleaner ;-)
* Tue Feb 21 2012 tittiatcoke@gmail.com
- Changed the parameters to plymouthd in the initrd to create
  the necessary pid-file for the systemd integration
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Ensure that /bin/plymouth still is available as that the
  displaymanagers (KDM/GDM) are expecting this. This needs to be
  in place until the migration to /usr is completed.
* Fri Feb 17 2012 tittiatcoke@gmail.com
- Finalize the Plymouth integration on openSUSE.
  * Current default theme is Solar with the openSUSE Geecko
  * Plymouth bootsplash will run on tty7 during boot.
  * Install all files in /usr
* Tue Dec 27 2011 crrodriguez@opensuse.org
- Update to current git
* Wed Mar 23 2011 jeffm@suse.de
- Update to git snapshot from 12 Mar 2011.
  - Mostly minor fixes.
* Sat Feb  5 2011 jeffm@suse.de
- Updated to latest snapshot.
  - boot-server: improve debug output
  - pixel-buffer: Fix overflow in blend_two_pixel_values
  - boot-server: fix debug output when message is from init
- Fixed an issue with the script plugin's Window attributes returning
  the size of the smallest display when multiple displays are used.
* Wed Dec 29 2010 jeffm@suse.de
- Fixed location of text.so and details.so in plymouth-scripts
* Wed Dec 22 2010 seife+obs@b1-systems.com
- fix the build failure:
  - own additional directories
- fix rpmlint failures:
  - fix up package groups - those are just guessed sometimes
  - rename plymouth-graphics-libs to libply-splash-graphics2
    (this one was fatal)
  - do not own /var/run/plymouth - probably still needs fixing
    (this was almost fatal)
  - do not include build date in binary, use mtime of source
    patchfile instead
* Wed Dec  8 2010 jeffm@suse.de
- Initial packaging.
